# cheshmak: body: v2

|   |   |   |
| --- | --- | --- |
| [![image](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_184658.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_184658.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_184702.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_184702.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_184706.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_184706.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_184712.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_184712.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_184717.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_184717.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_184723.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_184723.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_190023.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_190023.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_190131.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_190131.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_190344.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/cheshmak/20251203_190344.jpg?raw=true) |
